@@ -23,12 +23,12 @@
 //   Inc. ,51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 //
 
-#include <kmainwindow.h>
+#include <tdemainwindow.h>
 
-class KVILIB_API KviTalMainWindow : public KMainWindow
+class KVILIB_API KviTalMainWindow : public TDEMainWindow
 {
 	Q_OBJECT
-  TQ_OBJECT
+  
 public:
 	KviTalMainWindow(TQWidget * par,const char * nam);
 	~KviTalMainWindow();
