@@ -82,9 +82,9 @@
 	#include "kvi_cryptcontroller.h"
 #endif
 
-#ifdef COMPILE_KDE_SUPPORT
-	#include <kwin.h>
-	#include <kdeversion.h>
+#ifdef COMPILE_TDE_SUPPORT
+	#include <twin.h>
+	#include <tdeversion.h>
 #endif
 
 #ifdef COMPILE_ON_WINDOWS
@@ -257,8 +257,8 @@ void KviWindow::demandAttention()
 		fwi.dwTimeout = 500;
 		FlashWindowEx(&fwi);
 #else
-	#ifdef COMPILE_KDE_SUPPORT
-		#if (KDE_VERSION_MAJOR >= 3) && (KDE_VERSION_MINOR >= 2)
+	#ifdef COMPILE_TDE_SUPPORT
+		#if (TDE_VERSION_MAJOR >= 3) && (TDE_VERSION_MINOR >= 2)
 			KWin::demandAttention(frame()->winId(),true);
 		#endif
 	#endif
@@ -274,8 +274,8 @@ void KviWindow::demandAttention()
 		fwi.dwTimeout = 500;
 		FlashWindowEx(&fwi);
 #else
-	#ifdef COMPILE_KDE_SUPPORT
-		#if (KDE_VERSION_MAJOR >= 3) && (KDE_VERSION_MINOR >= 2)
+	#ifdef COMPILE_TDE_SUPPORT
+		#if (TDE_VERSION_MAJOR >= 3) && (TDE_VERSION_MINOR >= 2)
 			KWin::demandAttention(winId(),true);
 		#endif
 	#endif
