@@ -42,9 +42,9 @@
 #include "libkvidockwidget.h"
 #include "kvi_doublebuffer.h"
 
-#ifdef COMPILE_KDE_SUPPORT
-	#include <kwin.h>
-	#include <kpopupmenu.h>
+#ifdef COMPILE_TDE_SUPPORT
+	#include <twin.h>
+	#include <tdepopupmenu.h>
 #else
 	#include <tqlabel.h>
 #endif
@@ -126,7 +126,7 @@ KviDockWidget::KviDockWidget(KviFrame * frm,const char * name)
 	#ifndef COMPILE_USE_QT4
 		setBackgroundMode(X11ParentRelative);
 	#endif
-	#ifdef COMPILE_KDE_SUPPORT
+	#ifdef COMPILE_TDE_SUPPORT
 		KWin::setSystemTrayWindowFor(winId(),frm->winId());
 	#endif
 #endif //!COMPILE_ON_WINDOWS
@@ -140,8 +140,8 @@ KviDockWidget::KviDockWidget(KviFrame * frm,const char * name)
 	
 	m_pAwayPopup = new KviTalPopupMenu(this);
 	
-#ifdef COMPILE_KDE_SUPPORT
-	m_pContextPopup = new KPopupMenu(this);
+#ifdef COMPILE_TDE_SUPPORT
+	m_pContextPopup = new TDEPopupMenu(this);
 	m_pContextPopup->insertTitle(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_KVIRC)),__tr2qs("KVIrc"));
 #else
 	m_pContextPopup = new KviTalPopupMenu(this);
@@ -301,26 +301,26 @@ static const char * idlemsgs[NIDLEMSGS]=
 	__tr("idle idle idle idle!")
 };
 
-#ifdef COMPILE_KDE_SUPPORT
-	extern Time qt_x_time;
+#ifdef COMPILE_TDE_SUPPORT
+	extern Time tqt_x_time;
 #endif
 
 void KviDockWidget::enterEvent( TQEvent* )
 {
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_TDE_SUPPORT
 	if(!g_pApp->focusWidget())
 	{
 		XEvent ev;
 		kvi_memset(&ev, 0, sizeof(ev));
-		ev.xfocus.display = qt_xdisplay();
+		ev.xfocus.display = tqt_xdisplay();
 		ev.xfocus.type = XFocusIn;
 		ev.xfocus.window = winId();
 		ev.xfocus.mode = NotifyNormal;
 		ev.xfocus.detail = NotifyAncestor;
-		Time time = qt_x_time;
-		qt_x_time = 1;
+		Time time = tqt_x_time;
+		tqt_x_time = 1;
 		g_pApp->x11ProcessEvent( &ev );
-		qt_x_time = time;
+		tqt_x_time = time;
 	}
 #endif
 }
@@ -665,7 +665,7 @@ static KviDockWidget * dockwidget_find(KviFrame *f)
 		dockwidget.show
 	@description:
 		Shows the dock widget for the current frame window.[br]
-		The dock widget is a small widget that docks in the KDE panel.[br]
+		The dock widget is a small widget that docks in the TDE panel.[br]
 		It shows a small icon of the earth and eventually displays four squares
 		that cover this icon: the bottom left square appears when there is some new
 		text in any console window, the square becomes red if the text is highlighted.[br]
@@ -853,4 +853,4 @@ KVIRC_MODULE(
 
 #include "libkvidockwidget_qt3.moc"
 
-#endif
\ No newline at end of file
+#endif
