@@ -43,7 +43,7 @@
 	#include <unistd.h>
 #endif
 
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_TDE_SUPPORT
 	#include <dcopclient.h>
 #endif
 
@@ -468,7 +468,7 @@ static bool system_kvs_fnc_dcop(KviKvsModuleFunctionCall *c)
 		}
 	}
 
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_TDE_SUPPORT
 
 	TQByteArray ba;
 	TQDataStream ds(ba, IO_WriteOnly);
